====================
*XSON* Release Notes
====================

.. start included documentation

1.0.3
=====

Summary of changes:

* Fixed doctest embedded in readme to meet the requirements of packaging.
* Improved testing to check the validity of package metadata.


1.0.2
=====

Summary of changes:

* Improved testing (on Python 3.8, on Windows, on macOS).
* Improved package metadata.
* Sphinx can be used to generate documentation.
* CI migrated from Travis CI to GitHub Actions.


1.0.1
=====

Summary of changes:

* Install instructions include pip.
* Automatic SemVer with the help of setuptools_scm.


1.0.0
=====

First release of *XSON*.

Summary of main features:

* Object serialization to and deserialization from JSONx XML documents.
* API-compatibility with the standard JSON package.
* Python 3 implementation.
